@@ -18,15 +18,6 @@ use constant BLOCK => 'edit_block';
 
 
 our $IMP = {};
-our $MAP = undef;
-our $PAM = undef;
-
-sub _reset_globals
-{
-    $flo::Editor::MAP = undef;
-    $flo::Editor::PAM = undef;
-}
-
 
 $::MKD_flo_Editor_LINKS = [];
 sub _LINKS_()       { return $::MKD_flo_Editor_LINKS      }
@@ -43,12 +34,10 @@ sub _SET_ETERNAL_($) {
 
 sub _MAP_()
 {
-    $MAP ||= do {
-	$ENV{MOD_PERL} and Apache->push_handlers ("PerlCleanupHandler", \&flo::Editor::_reset_globals);
-	_construct_component_list();
-    };
-    
-    return $MAP;
+    my $dir = $ENV{SITE_DIR};
+    $::P_MKD_EDITOR_MAP         ||= {};
+    $::P_MKD_EDITOR_MAP->{$dir} ||= _construct_component_list();
+    return $::P_MKD_EDITOR_MAP->{$dir};
 }
 
 
