@@ -934,6 +934,14 @@ sub parent
 }
 
 
+sub parent_showable
+{
+    my $self = shift;
+    return $self->parent (@_);
+}
+
+
+
 ##
 # $self->set_parent ($parent);
 # ----------------------------
