@@ -4,7 +4,6 @@
 #
 #       Author : Steve Purkis <spurkis@mkdoc.com>
 #    Copyright : (c) MKDoc Holdings Ltd, 2002.
-#      Version : $Id: Preferences.pm,v 1.11.2.5 2004/01/08 17:20:02 jhiver Exp $
 #
 #       Unauthorized modification, use, reuse, distribution or redistribution
 #       of this module is stricly forbidden.
@@ -76,7 +75,7 @@ use base qw/ Exporter /;
 ##
 
 ## Version (from CVS revision string).
-our $VERSION = (split(/ /, '$Revision: 1.11.2.5 $'))[1];
+our $VERSION = (split(/ /, '$Revision: 1.11.2.8 $'))[1];
 
 
 ## Boolean switch controlling debug printing to STDERR.
@@ -395,17 +394,13 @@ sub _create_general_pref ($$)
 sub generals($)
 {
     my $self = shift;
-    my @GENERALS;
-
-    unless (exists $self->{_generals_})
-    {
-	my $cfg      = new MKDoc::Config('User.Preferences.general');
-	my %GENERALS = $cfg->hash;
-	@GENERALS    = 	map { { name => $_, label => $GENERALS{$_} } } sort keys %GENERALS;
-	$self->{_generals_} = [ @GENERALS ];
-    }
-
-    return wantarray ? @{$self->{_generals_}} : $self->{_generals_};
+    my @generals = (
+        { 'name' => 'newsletter-daily',   'label' => 'newsletter-daily' },
+        { 'name' => 'newsletter-monthly', 'label' => 'newsletter-monthly' },
+        { 'name' => 'newsletter-weekly',  'label' => 'newsletter-weekly' }
+    );
+    
+    return wantarray ? @generals : \@generals; 
 }
 
 
@@ -868,7 +863,7 @@ sub is_selected
     my $self = shift;
     my $name = shift;
     my $preference_t = flo::Standard::table ('Preference');
-    my $preference = $preference_t->get (Name => $name) || return;
+    my $preference = $preference_t->get (Name => $name, Editor_ID => $self->user()->id()) || return;
     $preference->{Value} ? return 'selected' : return;
 }
 
